#delimit ; 
*********************************************************************
*********************************************************************

**************** MODIFIED REGRESSION BRIDGING METHOD ****************

*********************************************************************
*********************************************************************

This program is designed to convert or 'bridge' multiple-race 
responses to single-race codes using only state-level geographic 
information. The method is termed the "modified regression method" 
because it is similar to (and based upon) the method and results 
reported in Ingram DD, Parker JD, Schenker N, Weed JA, Hamilton B, 
Arias E, Madans JH. "United States Census 2000 Population with 
Bridged Race Categories." National Center for Health Statistics. 
Vital Health Stat 2(135). 2003.

The following abbreviations are used below: 
 AIAN = American Indian and/or Alaska Native
 API = Asian and/or Pacific Islander
 B = black or African American
 W = white
 SOR = "some other race" 
 
To learn more about this program and/or the variables it creates, 
see Liebler CA and Halpern-Manners A. "A Practical Approach to Using 
Multiple-Race Response Data: A Bridging Method for Public-Use Microdata" 
Demography. 2007. Please cite this program by citing the Liebler and 
Halpern-Manners article.

*********************************************************************
*********************************************************************

INPUT VARIABLES TO BE USED BY THE PROGRAM

*********************************************************************
*********************************************************************

The following variables are used in the program and must be provided 
for each individual in the input file. "Some other race" responses 
are ignored if any other races are reported. Note that variable names 
are case-sensitive in STATA.

MRMRACE 
1  = AIAN and API
2  = AIAN and B
3  = AIAN and W
4  = API and B
5  = API and W
6  = B and W
7  = AIAN and API and B
8  = AIAN and API and W
9  = AIAN and B and W
10 = API and B and W
11 = AIAN and API and B and W

20 = AIAN only
30 = API only
40 = B only
50 = W only
60 = SOR only

AGE10
continuous variable -- respondent's age divided by 10

HISP
0 = not Spanish, Hispanic, or Latino
1 = of Spanish, Hispanic, or Latino origin

MALE
0 = female
1 = male

STATEFIP
FIPS coding is used for all states and Washington, DC
01 = Alabama 
02 = Alaska 
04 = Arizona 
05 = Arkansas 
06 = California 
08 = Colorado 
09 = Connecticut 
10 = Delaware 
11 = District of Columbia 
12 = Florida 
13 = Georgia 
15 = Hawaii 
16 = Idaho 
17 = Illinois 
18 = Indiana  
19 = Iowa 
20 = Kansas 
21 = Kentucky 
22 = Louisiana 
23 = Maine 
24 = Maryland 
25 = Massachusetts 
26 = Michigan 
27 = Minnesota 
28 = Mississippi 
29 = Missouri 
30 = Montana 
31 = Nebraska 
32 = Nevada 
33 = New Hampshire 
34 = New Jersey 
35 = New Mexico 
36 = New York 
37 = North Carolina 
38 = North Dakota 
39 = Ohio 
40 = Oklahoma 
41 = Oregon 
42 = Pennsylvania 
44 = Rhode Island 
45 = South Carolina 
46 = South Dakota 
47 = Tennessee 
48 = Texas 
49 = Utah 
51 = Virginia 
50 = Vermont 
53 = Washington 
54 = West Virginia 
55 = Wisconsin 
56 = Wyoming

*********************************************************************
*********************************************************************

CREATING THE INPUT VARIABLES USING VARIABLES FROM IPUMS.ORG

*********************************************************************
*********************************************************************

-------------------------------------------------
Variables to request from IPUMS extraction system
-------------------------------------------------
year datanum statefip serial pernum sex age hispan(general) 
racamind racasian racblk racother racpacis racwht racnum
-------------------------------------------------

This sub-program uses variables provided by www.ipums.org to create 
the input variables. To use this sub-program, request the listed 
variables from the IPUMS extract system and remove all '*' from 
the remainder of this section.     ;

* #delimit ; 
 
 gen racapi = 1; 
 replace racapi = 2 if racasian==2 | racpacis==2; 
 
 gen MRMRACE = . ; 
 replace MRMRACE = 1 if racamind==2 & racapi==2 & racblk==1 & racwht==1; 
 replace MRMRACE = 2 if racamind==2 & racapi==1 & racblk==2 & racwht==1; 
 replace MRMRACE = 3 if racamind==2 & racapi==1 & racblk==1 & racwht==2; 
 replace MRMRACE = 4 if racamind==1 & racapi==2 & racblk==2 & racwht==1; 
 replace MRMRACE = 5 if racamind==1 & racapi==2 & racblk==1 & racwht==2; 
 replace MRMRACE = 6 if racamind==1 & racapi==1 & racblk==2 & racwht==2; 
 replace MRMRACE = 7 if racamind==2 & racapi==2 & racblk==2 & racwht==1; 
 replace MRMRACE = 8 if racamind==2 & racapi==2 & racblk==1 & racwht==2; 
 replace MRMRACE = 9 if racamind==2 & racapi==1 & racblk==2 & racwht==2;
 replace MRMRACE = 10 if racamind==1 & racapi==2 & racblk==2 & racwht==2; 
 replace MRMRACE = 11 if racamind==2 & racapi==2 & racblk==2 & racwht==2;
 replace MRMRACE = 20 if racamind==2 & racapi==1 & racblk==1 & racwht==1; 
 replace MRMRACE = 30 if racamind==1 & racapi==2 & racblk==1 & racwht==1; 
 replace MRMRACE = 40 if racamind==1 & racapi==1 & racblk==2 & racwht==1; 
 replace MRMRACE = 50 if racamind==1 & racapi==1 & racblk==1 & racwht==2; 
 replace MRMRACE = 60 if racother==2 & racnum==1; 
 
 gen AGE10 = age/10; 
 
 gen HISP = 1 ; 
 replace HISP=0 if hispan==0; 
 
 gen MALE = 0 if sex==2; 
 replace MALE = 1 if sex==1; 
 
 gen STATEFIP = statefip; 

*********************************************************************
*********************************************************************

OUTPUT VARIABLES CREATED BY THE PROGRAM

*********************************************************************
*********************************************************************

The following variables are created by this program. The four "PROB" 
variables range from 0 to 1 and sum to 1. ONERACE is the single race 
most likely to have been reported by that individual if he/she was 
forced to choose. 
 
AIPROB  = probability of reporting American Indian and/or Alaskan Native
APIPROB = probability of reporting Asian and/or Pacific Islander
BPROB = probability of reporting black/African American
WPROB = probability of reporting white
 
ONERACE = historically compatible bridged single race 
1 = American Indian and/or Alaska Native
2 = Asian and/or Pacific Islander
3 = Black/African American
4 = White
 
*********************************************************************
*********************************************************************

THE MODIFIED REGRESSION METHOD BRIDGING PROGRAM

*********************************************************************
*********************************************************************
;
* Source: The racial composition of states as of April 1, 2000 
are from Ingram et al. 2003, Table 2, which was derived from 
the Census 2000 Modified Race Data Summary File;

gen lnpctAI=0;	
 label variable lnpctAI "natural log of %AI in state";
replace lnpctAI=	0.182321557	if STATEFIP==	6	; 
				
gen pctAI=0;	
 label variable pctAI "% Am.Ind. in state";			
replace pctAI=	1.2	if STATEFIP==	6	; 


gen pctAPI=0; 				
 label variable pctAPI "% Asian or PI in state";		
replace pctAPI=	11.8	if STATEFIP==	6	; 
				
gen pctB=0; 						
 label variable pctB "% Black in state";		
replace pctB=	7	if STATEFIP==	6	; 
				
gen pctBsq=0; 				
  label variable pctBsq "% Black in state, squared";
replace pctBsq=	49	if STATEFIP==	6	; 

gen pct2race=0;	
 label variable pct2race "% 2+ races or non-Hisp 'other' in state";		
replace pct2race=	2.2	if STATEFIP==	6	; 

* 14 states have no cities of more than 1 million population; 
* source for total state pop & # not metro: Census table GCT-PH1: state;

gen medmetro= 0;
 label variable medmetro "MSA less than 1 million";

gen nonmetro= 0;
 label variable nonmetro "not in metro area";

* 11 states and DC have 1+ 'big' city and no big cities cross 
  its state lines;
* source for central city population is: Census table GCT-PH1: 
  Population, Housing Units, Area, and Density: 2000 (SF1) 
  US and PR -- Metropolitan Area, in Central City, Not in 
  Central City, County, and (in selected States) County Subdivision;
  
gen bigurban= 0; 
 label variable bigurban "in central city, MSA >= 1 million";
replace bigurban=	0.30194982	 if STATEFIP==	6	;

gen bigsubrb= 0;
 label variable bigsubrb "outside central city, MSA >= 1 million";
replace bigsubrb=	0.461780454	 if STATEFIP==	6	;

replace medmetro=	0.203166702	 if STATEFIP==	6	;

replace nonmetro=	0.033103025	 if STATEFIP==	6	;

* 25 states have at least one city that crosses state lines;
* Source for proportions of city populations in each state: Census 
  table GCT-PH1: Population, Housing Units Area, and Density: 2000 (SF1)
; 


gen AIPROB=0; 
label variable AIPROB  "probability of reporting Am. Ind. and/or Alaskan Native";
replace AIPROB=1 if MRMRACE==20; 
gen APIPROB=0; 
label variable APIPROB "probability of reporting Asian and/or PI";
replace APIPROB=1 if MRMRACE==30; 
gen BPROB=0; 
label variable BPROB "probability of reporting black";
replace BPROB=1 if MRMRACE==40; 
gen WPROB=0; 
label variable WPROB "probability of reporting white";
replace WPROB=1 if MRMRACE==50; 

gen constant=1;
gen notAI=0 ;   replace notAI=1 if MRMRACE==10;
gen notAPI=0; 
gen notB=0  ;    replace notB=1 if MRMRACE==1 | MRMRACE==8;

gen northest= 0; replace northest=1 if STATEFIP==09 | STATEFIP==23 |  
STATEFIP==25 | STATEFIP==33 | STATEFIP==34 | STATEFIP==36 |  
STATEFIP==42 | STATEFIP==44 | STATEFIP==50;
 label variable northest "northeast region";

gen midwest= 0; replace midwest=1 if STATEFIP==17 | STATEFIP==18 | 
STATEFIP==19 | STATEFIP==20 | STATEFIP==26 | STATEFIP==27 |  
STATEFIP==29 | STATEFIP==31 | STATEFIP==38 | STATEFIP==39 |  
STATEFIP==46 | STATEFIP==55;
 label variable midwest "midwest region";

gen south= 0; replace south=1 if STATEFIP==01 | STATEFIP==05 | 
STATEFIP==10 | STATEFIP==11 | STATEFIP==12 | STATEFIP==13 | 
STATEFIP==21 | STATEFIP==22 | STATEFIP==24 | STATEFIP==28 | 
STATEFIP==37 | STATEFIP==40 | STATEFIP==45 | STATEFIP==47 | 
STATEFIP==48 | STATEFIP==51 | STATEFIP==54; 
 label variable south "south region";
 
gen west=0; replace west=1 if STATEFIP==02 | STATEFIP==04 | 
STATEFIP==06 | STATEFIP==08 | STATEFIP==15 | STATEFIP==16 | 
STATEFIP==30 | STATEFIP==32 | STATEFIP==35 | STATEFIP==41 | 
STATEFIP==49 | STATEFIP==53 | STATEFIP==56; 
 label variable west "west region";

* MRMRACE=1 IS AI-API    ==> predict AI and API, then rescale;
gen mrm1AI =0; label variable mrm1AI "regression answer: AI, MRD group 1";
replace mrm1AI =
 (notAI    *   0) +
 (notAPI   *   2.83058) + 
 (notB     *   0.97010) + 
 (AGE10    *  -0.03967) + 
 (HISP     *   0.84013) + 
 (MALE     *   0.01914) + 
 (northest *   0.59649) + 
 (midwest  *   0.43237) +
 (south    *  -0.22255) + 
 (bigsubrb *   0.15744) + 
 (medmetro *  -0.17318) + 
 (nonmetro *   0.25013) + 
 (lnpctAI  *   0.56512) +
 (pctAPI   *   0.04203) + 
 (pctB     *   0.03921) + 
 (pct2race *  -0.09723) + 
 (constant *  -5.29417)
if MRMRACE==1;
gen AItemp1= exp(mrm1AI)/(1+exp(mrm1AI)) if MRMRACE==1;

gen mrm1API =0; label variable mrm1API "regression answer: API, MRD group 1";
replace mrm1API =
 (notAI    *   2.78725) +
 (notAPI   *   0) + 
 (notB     *   1.61570) + 
 (AGE10    *   0.01946) + 
 (HISP     *   0.21507) + 
 (MALE     *   0.01283) + 
 (northest *  -0.13221) + 
 (midwest  *  -0.15172) +
 (south    *  -0.24854) + 
 (bigsubrb *   0.46028) + 
 (medmetro *  -0.09493) + 
 (nonmetro *  -0.15342) + 
 (lnpctAI  *   0.06996) +
 (pctAPI   *   0.03741) + 
 (pctB     *   0.03590) + 
 (pct2race *   0.06402) + 
 (constant *  -5.73987)
if MRMRACE==1;
gen APItemp1= exp(mrm1API)/(1+exp(mrm1API)) if MRMRACE==1;

gen rescale1=1/(AItemp1+APItemp1); 
replace AIPROB = AItemp1 * rescale1 if MRMRACE==1;
replace APIPROB = APItemp1 * rescale1 if MRMRACE==1;
drop  mrm1AI AItemp1 mrm1API APItemp1 rescale1;

* MRMRACE=2 IS AI-B   ==> predict Black; 
gen mrm2B =0; label variable mrm2B "regression answer: Black, MRD group 2";
replace mrm2B =
 (AGE10    *  -0.05461) + 
 (HISP     *  -1.92602) + 
 (MALE     *  -0.12359) + 
 (northest *  -0.88349) + 
 (midwest  *  -1.70126) +
 (south    *  -0.97935) + 
 (bigsubrb *  -0.44211) + 
 (medmetro *   0.88281) + 
 (nonmetro *  -0.38427) + 
 (lnpctAI  *  -0.43045) +
 (pctBsq   * 0.0000258) + 
 (pct2race *  -0.16934) + 
 (constant *   3.08086)
if MRMRACE==2;
replace BPROB= exp(mrm2B)/(1+exp(mrm2B)) if MRMRACE==2; 
replace AIPROB= 1-BPROB if MRMRACE==2; 
drop mrm2B;

* MRMRACE=3 IS AI-W   ==> predict AI ; 
gen mrm3AI =0; label variable mrm3AI "regression answer: AI, MRD group 3";
replace mrm3AI =
 (AGE10    *  -0.08968) + 
 (HISP     *   0.88834) + 
 (MALE     *   0.00972) + 
 (northest *   0.21233) + 
 (midwest  *   0.09144) +
 (south    *  -0.28494) + 
 (bigsubrb *  -0.22069) + 
 (medmetro *  -0.44238) + 
 (nonmetro *  -0.13978) + 
 (lnpctAI  *   0.51235) +
 (pct2race *  -0.07906) + 
 (constant *  -0.70527) 
if MRMRACE==3;
replace AIPROB= exp(mrm3AI)/(1+exp(mrm3AI)) if MRMRACE==3; 
replace WPROB= 1-AIPROB if MRMRACE==3; 
drop mrm3AI;

* MRMRACE=4 IS API-B  ==> predict Black;
gen mrm4B =0; label variable mrm4B "regression answer: Black, MRD group 4";
replace mrm4B =
 (AGE10    *  0.05669) + 
 (HISP     * -0.10458) + 
 (MALE     *  0.33642) + 
 (northest * -0.45997) + 
 (midwest  * -3.92403) +
 (south    * -1.48264) + 
 (bigsubrb *  1.46590) + 
 (medmetro *  1.67953) + 
 (nonmetro *  0.13301) + 
 (pctAPI   * -0.13245) +
 (pctB     *  0.02078) + 
 (pct2race *  0.31250) + 
 (constant *  0.45883)
if MRMRACE==4;
replace BPROB= exp(mrm4B)/(1+exp(mrm4B)) if MRMRACE==4; 
replace APIPROB= 1-BPROB if MRMRACE==4; 
drop mrm4B;

* MRMRACE=5 IS API-W  ==> predict API ;
gen mrm5API =0; label variable mrm5API "regression answer: API, MRD group 5";
replace mrm5API =
 (AGE10    *  0.09568) + 
 (HISP     *  0.19303) + 
 (MALE     *  0.01393) + 
 (northest * -0.05520) + 
 (midwest  * -0.06453) +
 (south    *  0.12694) + 
 (bigsubrb *  0.50556) + 
 (medmetro *  0.07443) + 
 (nonmetro * -0.62956) + 
 (pctAPI   *  0.00735) +
 (pct2race *  0.09791) + 
 (constant * -1.18887)
if MRMRACE==5;
replace APIPROB= exp(mrm5API)/(1+exp(mrm5API)) if MRMRACE==5; 
replace WPROB= 1-APIPROB if MRMRACE==5; 
drop mrm5API;

* MRMRACE=6 IS B-W    ==> predict Black;
gen mrm6B =0; label variable mrm6B "regression answer: Black, MRD group 6";
replace mrm6B =
 (AGE10    *  0.05532) + 
 (HISP     * -0.52253) + 
 (MALE     *  0.11948) + 
 (northest * -0.25363) + 
 (midwest  *  0.17140) +
 (south    * -0.64386) + 
 (bigsubrb * -0.07649) + 
 (medmetro *  0.28938) + 
 (nonmetro *  0.57636) + 
 (pctBsq   *  0.00079) + 
 (pct2race *  0.31679) + 
 (constant * -0.17533)
if MRMRACE==6;
replace BPROB= exp(mrm6B)/(1+exp(mrm6B)) if MRMRACE==6; 
replace WPROB= 1-BPROB if MRMRACE==6; 
drop mrm6B;

* MRMRACE=7 IS AI-API-B  ==> predict AI, API, and B, then rescale;
gen mrm7AI =0; label variable mrm7AI "regression answer: AI, MRD group 7";
replace mrm7AI =
 (notAI    *   0) +
 (notAPI   *   2.83058) + 
 (notB     *   0.97010) + 
 (AGE10    *  -0.03967) + 
 (HISP     *   0.84013) + 
 (MALE     *   0.01914) + 
 (northest *   0.59649) + 
 (midwest  *   0.43237) +
 (south    *  -0.22255) + 
 (bigsubrb *   0.15744) + 
 (medmetro *  -0.17318) + 
 (nonmetro *   0.25013) + 
 (lnpctAI  *   0.56512) +
 (pctAPI   *   0.04203) + 
 (pctB     *   0.03921) + 
 (pct2race *  -0.09723) + 
 (constant *  -5.29417)
if MRMRACE==7;

gen mrm7API =0; label variable mrm7API "regression answer: API, MRD group 7";
replace mrm7API =
 (notAI    *   2.78725) +
 (notAPI   *   0) + 
 (notB     *   1.61570) + 
 (AGE10    *   0.01946) + 
 (HISP     *   0.21507) + 
 (MALE     *   0.01283) + 
 (northest *  -0.13221) + 
 (midwest  *  -0.15172) +
 (south    *  -0.24854) + 
 (bigsubrb *   0.46028) + 
 (medmetro *  -0.09493) + 
 (nonmetro *  -0.15342) + 
 (lnpctAI  *   0.06996) +
 (pctAPI   *   0.03741) + 
 (pctB     *   0.03590) + 
 (pct2race *   0.06402) + 
 (constant *  -5.73987)
if MRMRACE==7;

gen mrm7B =0; label variable mrm7B "regression answer: B, MRD group 7";
replace mrm7B =
 (notAI    *   2.19772) +
 (notAPI   *   3.06153) + 
 (notB     *   0) + 
 (AGE10    *  -0.01691) + 
 (HISP     *  -0.58721) + 
 (MALE     *  -0.08093) + 
 (northest *   0.40115) + 
 (midwest  *   0.20136) +
 (south    *  -0.29365) + 
 (bigsubrb *   0.12070) + 
 (medmetro *  -0.11129) + 
 (nonmetro *  -0.12077) + 
 (lnpctAI  *  -0.00347) +
 (pctAPI   *   0.05396) + 
 (pctB     *   0.05893) + 
 (pct2race *  -0.03953) + 
 (constant *  -5.21431)
if MRMRACE==7;

gen AItemp7= exp(mrm7AI)/(1+exp(mrm7AI)+exp(mrm7API)+exp(mrm7B)) if MRMRACE==7;
gen APItemp7= exp(mrm7API)/(1+exp(mrm7AI)+exp(mrm7API)+exp(mrm7B)) if MRMRACE==7;
gen Btemp7= exp(mrm7B)/(1+exp(mrm7AI)+exp(mrm7API)+exp(mrm7B)) if MRMRACE==7;
gen resc7=AItemp7+APItemp7+Btemp7 if MRMRACE==7;
gen rescale7=1/resc7;  
replace AIPROB  = AItemp7  * rescale7 if MRMRACE==7;
replace APIPROB = APItemp7 * rescale7 if MRMRACE==7;
replace BPROB = Btemp7   * rescale7 if MRMRACE==7;
drop  mrm7AI mrm7API mrm7B APItemp7 AItemp7 Btemp7 resc7 rescale7;

* MRMRACE=8 IS AI-API-W  ==> predict AI and API, white is remainder;
gen mrm8AI =0; label variable mrm8AI "regression answer: AI, MRD group 8";
replace mrm8AI =
 (notAI    *   0) +
 (notAPI   *   2.83058) + 
 (notB     *   0.97010) + 
 (AGE10    *  -0.03967) + 
 (HISP     *   0.84013) + 
 (MALE     *   0.01914) + 
 (northest *   0.59649) + 
 (midwest  *   0.43237) +
 (south    *  -0.22255) + 
 (bigsubrb *   0.15744) + 
 (medmetro *  -0.17318) + 
 (nonmetro *   0.25013) + 
 (lnpctAI  *   0.56512) +
 (pctAPI   *   0.04203) + 
 (pctB     *   0.03921) + 
 (pct2race *  -0.09723) + 
 (constant *  -5.29417) 
if MRMRACE==8;

gen mrm8API =0; label variable mrm8API "regression answer: API, MRD group 8";
replace mrm8API =
 (notAI    *   2.78725) +
 (notAPI   *   0) + 
 (notB     *   1.61570) + 
 (AGE10    *   0.01946) + 
 (HISP     *   0.21507) + 
 (MALE     *   0.01283) + 
 (northest *  -0.13221) + 
 (midwest  *  -0.15172) +
 (south    *  -0.24854) + 
 (bigsubrb *   0.46028) + 
 (medmetro *  -0.09493) + 
 (nonmetro *  -0.15342) + 
 (lnpctAI  *   0.06996) +
 (pctAPI   *   0.03741) + 
 (pctB     *   0.03590) + 
 (pct2race *   0.06402) + 
 (constant *  -5.73987) 
if MRMRACE==8;

replace AIPROB = exp(mrm8AI) /(1+exp(mrm8AI)+exp(mrm8API)) if MRMRACE==8; 
replace APIPROB= exp(mrm8API)/(1+exp(mrm8AI)+exp(mrm8API)) if MRMRACE==8; 
replace WPROB= 1-AIPROB-APIPROB if MRMRACE==8; 
drop mrm8AI mrm8API; 

* MRMRACE=9 IS AI-B-W ==> predict AI and B, white is remainder;

gen mrm9AI =0; label variable mrm9AI "regression answer: AI, MRD group 9";
replace mrm9AI =
 (AGE10    *  0.26212) + 
 (HISP     *  0.35986) + 
 (MALE     * -0.43898) + 
 (northest * -4.53976) + 
 (midwest  * -3.82328) +
 (south    * -5.73385) + 
 (bigsubrb *  2.78910) + 
 (medmetro *  2.27176) + 
 (nonmetro *  4.17804) + 
 (pctAI    *  0.54579) +
 (pctB     *  0.11100) + 
 (pct2race * -0.23972) + 
 (constant * -0.64594)
if MRMRACE==9;

gen mrm9B =0; label variable mrm9B "regression answer: B, MRD group 9";
replace mrm9B =
 (AGE10    *  0.36140) + 
 (HISP     * -0.83526) + 
 (MALE     *  0.50777) + 
 (northest * -3.45593) + 
 (midwest  * -3.79144) +
 (south    * -2.27313) + 
 (bigsubrb *  2.31011) + 
 (medmetro *  0.75477) + 
 (nonmetro *  1.64725) + 
 (pctAI    *  0.39101) +
 (pctB     *  0.04985) + 
 (pct2race * -0.02919) + 
 (constant *  0.77004)
if MRMRACE==9;

replace AIPROB= exp(mrm9AI)/(1+exp(mrm9AI)+exp(mrm9B)) if MRMRACE==9; 
replace BPROB= exp(mrm9B)/(1+exp(mrm9AI)+exp(mrm9B)) if MRMRACE==9; 
replace WPROB=1-BPROB-AIPROB if MRMRACE==9;
drop mrm9AI mrm9B;

* MARS=10 IS API-B-W  ==> predict API and B, white is remainder;
gen mrm10AP =0; label variable mrm10AP "regression answer: API, MRD group 10";
replace mrm10AP =
 (notAI    *   2.78725) +
 (notAPI   *   0) + 
 (notB     *   1.61570) + 
 (AGE10    *   0.01946) + 
 (HISP     *   0.21507) + 
 (MALE     *   0.01283) + 
 (northest *  -0.13221) + 
 (midwest  *  -0.15172) +
 (south    *  -0.24854) + 
 (bigsubrb *   0.46028) + 
 (medmetro *  -0.09493) + 
 (nonmetro *  -0.15342) + 
 (lnpctAI  *   0.06996) +
 (pctAPI   *   0.03741) + 
 (pctB     *   0.03590) + 
 (pct2race *   0.06402) + 
 (constant *  -5.73987)
if MRMRACE==10;

gen mrm10B =0; label variable mrm10B "regression answer: B, MRD group 10";
replace mrm10B =
 (notAI    *   2.19772) +
 (notAPI   *   3.06153) + 
 (notB     *   0) + 
 (AGE10    *  -0.01691) + 
 (HISP     *  -0.58721) + 
 (MALE     *  -0.08093) + 
 (northest *   0.40115) + 
 (midwest  *   0.20136) +
 (south    *  -0.29365) + 
 (bigsubrb *   0.12070) + 
 (medmetro *  -0.11129) + 
 (nonmetro *  -0.12077) + 
 (lnpctAI  *  -0.00347) +
 (pctAPI   *   0.05396) + 
 (pctB     *   0.05893) + 
 (pct2race *  -0.03953) + 
 (constant *  -5.21431)
if MRMRACE==10;

replace APIPROB= exp(mrm10AP)/(1+exp(mrm10AP)+exp(mrm10B)) if MRMRACE==10; 
replace BPROB= exp(mrm10B)/(1+exp(mrm10AP)+exp(mrm10B)) if MRMRACE==10; 
replace WPROB=1-BPROB-APIPROB if MRMRACE==10;
drop mrm10AP mrm10B;

* MARS=11 IS AI-API-B-W ==> predict AI, API, and B, white is remainder;
gen mrm11AI =0; label variable mrm11AI "regression answer: AI, MRD group 11";
replace mrm11AI =
 (notAI    *   0) +
 (notAPI   *   2.83058) + 
 (notB     *   0.97010) + 
 (AGE10    *  -0.03967) + 
 (HISP     *   0.84013) + 
 (MALE     *   0.01914) + 
 (northest *   0.59649) + 
 (midwest  *   0.43237) +
 (south    *  -0.22255) + 
 (bigsubrb *   0.15744) + 
 (medmetro *  -0.17318) + 
 (nonmetro *   0.25013) + 
 (lnpctAI  *   0.56512) +
 (pctAPI   *   0.04203) + 
 (pctB     *   0.03921) + 
 (pct2race *  -0.09723) + 
 (constant *  -5.29417)
if MRMRACE==11;

gen mrm11AP =0; label variable mrm11AP "regression answer: API, MRD group 11";
replace mrm11AP =
 (notAI    *   2.78725) +
 (notAPI   *   0) + 
 (notB     *   1.61570) + 
 (AGE10    *   0.01946) + 
 (HISP     *   0.21507) + 
 (MALE     *   0.01283) + 
 (northest *  -0.13221) + 
 (midwest  *  -0.15172) +
 (south    *  -0.24854) + 
 (bigsubrb *   0.46028) + 
 (medmetro *  -0.09493) + 
 (nonmetro *  -0.15342) + 
 (lnpctAI  *   0.06996) +
 (pctAPI   *   0.03741) + 
 (pctB     *   0.03590) + 
 (pct2race *   0.06402) + 
 (constant *  -5.73987)
if MRMRACE==11;

gen mrm11B =0; label variable mrm11B "regression answer: B, MRD group 11";
replace mrm11B =
 (notAI    *   2.19772) +
 (notAPI   *   3.06153) + 
 (notB     *   0) + 
 (AGE10    *  -0.01691) + 
 (HISP     *  -0.58721) + 
 (MALE     *  -0.08093) + 
 (northest *   0.40115) + 
 (midwest  *   0.20136) +
 (south    *  -0.29365) + 
 (bigsubrb *   0.12070) + 
 (medmetro *  -0.11129) + 
 (nonmetro *  -0.12077) + 
 (lnpctAI  *  -0.00347) +
 (pctAPI   *   0.05396) + 
 (pctB     *   0.05893) + 
 (pct2race *  -0.03953) + 
 (constant *  -5.21431)
if MRMRACE==11;

replace AIPROB= exp(mrm11AI)/(1+exp(mrm11AI)+exp(mrm11AP)+exp(mrm11B)) if MRMRACE==11; 
replace APIPROB= exp(mrm11AP)/(1+exp(mrm11AI)+exp(mrm11AP)+exp(mrm11B)) if MRMRACE==11; 
replace BPROB= exp(mrm11B)/(1+exp(mrm11AI)+exp(mrm11AP)+exp(mrm11B)) if MRMRACE==11; 
replace WPROB=1-AIPROB-APIPROB-BPROB if MRMRACE==11;
drop mrm11AI mrm11AP mrm11B;

drop  lnpctAI pctAI pctAPI pctB pctBsq pct2race medmetro nonmetro 
bigurban bigsubrb constant notAI notAPI notB northest midwest south west;

* Note: When converting probabilities to ONERACE, equal probabilities 
are decided in favor of the single-race group that has a higher average 
probability listed in Table 9 of Ingram et al. 2003.;

gen ONERACE=0; 
replace ONERACE=1 if MRMRACE==20; 
replace ONERACE=2 if MRMRACE==30; 
replace ONERACE=3 if MRMRACE==40; 
replace ONERACE=4 if MRMRACE==50; 
replace ONERACE=5 if MRMRACE==60;

replace ONERACE=1 if MRMRACE==1 & AIPROB>0.5; 
replace ONERACE=2 if MRMRACE==1 & APIPROB>=0.5; 

replace ONERACE=1 if MRMRACE==2 & AIPROB>0.5; 
replace ONERACE=3 if MRMRACE==2 & BPROB>=0.5; 

replace ONERACE=1 if MRMRACE==3 & AIPROB>0.5; 
replace ONERACE=4 if MRMRACE==3 & WPROB>=0.5; 

replace ONERACE=2 if MRMRACE==4 & APIPROB>0.5; 
replace ONERACE=3 if MRMRACE==4 & BPROB>=0.5; 

replace ONERACE=2 if MRMRACE==5 & APIPROB>0.5; 
replace ONERACE=4 if MRMRACE==5 & WPROB>=0.5; 

replace ONERACE=4 if MRMRACE==6 & WPROB>0.5; 
replace ONERACE=3 if MRMRACE==6 & BPROB>=0.5; 

replace ONERACE=2 if MRMRACE==7 & APIPROB>BPROB   & APIPROB>AIPROB; 
replace ONERACE=1 if MRMRACE==7 & AIPROB>=APIPROB & AIPROB>BPROB;
replace ONERACE=3 if MRMRACE==7 & BPROB>=APIPROB  & BPROB>=AIPROB;

replace ONERACE=1 if MRMRACE==8 & AIPROB>APIPROB  & AIPROB>WPROB;
replace ONERACE=2 if MRMRACE==8 & APIPROB>=AIPROB & APIPROB>WPROB;
replace ONERACE=4 if MRMRACE==8 & WPROB>=AIPROB   & WPROB>=APIPROB;

replace ONERACE=1 if MRMRACE==9 & AIPROB>BPROB    & AIPROB>WPROB; 
replace ONERACE=4 if MRMRACE==9 & WPROB>=AIPROB   & WPROB>BPROB;
replace ONERACE=3 if MRMRACE==9 & BPROB>=AIPROB   & BPROB>=WPROB;

replace ONERACE=2 if MRMRACE==10 & APIPROB>BPROB  & APIPROB>WPROB;
replace ONERACE=3 if MRMRACE==10 & BPROB>=APIPROB & BPROB>WPROB;
replace ONERACE=4 if MRMRACE==10 & WPROB>=APIPROB & WPROB>=BPROB;

replace ONERACE=2 if MRMRACE==11 & APIPROB>AIPROB & APIPROB>BPROB & APIPROB>WPROB;
replace ONERACE=1 if MRMRACE==11 & AIPROB>=APIPROB & AIPROB>BPROB & AIPROB>WPROB;
replace ONERACE=3 if MRMRACE==11 & BPROB>=APIPROB & BPROB>=AIPROB & BPROB>WPROB;
replace ONERACE=4 if MRMRACE==11 & WPROB>=APIPROB & WPROB>=AIPROB & WPROB>=BPROB;

label variable ONERACE "bridged single race"; 
label define oneracelbl 1 "Am.Ind." 2 "Asian/PI" 3 "black" 4 "white" 5 "SOR";
label values ONERACE oneracelbl;
